.. _compute_test_stat:

`compute_test_stat`
===================

.. automodule:: oasis_stat
   :members: compute_test_stat
   :undoc-members:
   :show-inheritance:
   :noindex:

Description
-----------
This function computes the test statistic for the OASIS test.